  /*****************************************************

  OLIMEXINO-32U4 + MOD-PULSE
  
  This example configures the OLIMEXINO-32U4 board (the
  board is similar to Arduino Leonardo) to read and print
  the values from MOD-PULSE and the SPO2-CABLE-NELLCOR-SENSOR.

  To use this example you must have some connector
  cable like the CABLE-IDC10-15cm UEXT to UEXT
  cable or use bare wires.
  
  Unplug the mini USB cable from the OLIMEXINO-32U4.
  Connect the SPO2-CABLE-NELLCOR-SENSOR to the
  MOD-PULSE DE-9 port. Connect the OLIMEXINO-32U4's
  UEXT port to the MOD-PULSE's UEXT port.
  
  Make sure that the BAT/UEXT switch is in position UEXT
  and the P_OUT jumper is closed - the OLIMEXINO-32U4
  will supply 3.3V to the MOD-PULSE through the UEXT, so
  no other power source should be connected to the MOD-PULSE.
  
  Plug the mini USB and upload the code to the board.
  
  Use some serial port terminal program to observe the
  values that the OLIMEXINO-32U4 read from the MOD-PULSE.
  
  Serial port settings:
  - 115200 baud rate
  - 8 data bits
  - no parity
  - 1 stop bit
  
  If you have any questions, email:
  
  support@olimex.com
  https://www.olimex.com
  May 2016
  
  *****************************************************/

byte i = 0;
byte tmpstr[5];
byte zsync = 0;
byte wait = 0;
byte cycle = 0;
char c;

#define DELAY 1000

void setup()
{
  delay(1000);
  Serial.begin(115200);   /* USB mini (your PC) */
  Serial1.begin(115200);  /* this is the UEXT port connected to the MOD-PULSE's UEXT port */
  pinMode(8, OUTPUT);
  digitalWrite(8, LOW);   /* enables power to the UEXT */
  delay(1000);
}

void loop()
{
  if(wait)
  {
    delay(DELAY);
    wait = 0;
  }
  if(Serial1.available())
  {
    c = Serial1.read();
    if((byte)c == 0x00)
    {
      cycle++;  /* wait a few zero synch bytes */
      zsync = 1;
      i = 0;
    }
    if(zsync == 1 && cycle == 10)
    {
      if((byte)c != 0xFF)
      {
        tmpstr[i] = c;
        if(i == 3)
        {
          Serial.println("\n\nSensor readings:");
          Serial.print("Infra-red AC heart signal:\t");
          Serial.println(tmpstr[1]);
          Serial.print("Heart Rate per minute:\t\t");
          Serial.println(tmpstr[2]);
          Serial.print("Percentage oxygen saturation:\t");
          Serial.println(tmpstr[3]);
          zsync = 0;
          wait = 1;
          cycle = 0;
        }
        i++;
      }
    }
  }
  if(wait)
  {
    delay(1000);
    wait = 0;
  }
}
